@@ -65,7 +65,7 @@ class New(CreateView):
 
     def get_context_data(self, **kwargs):
         context = super().get_context_data(**kwargs)
-        context["page_title"] = _("New bug")
+        context["page_title"] = _("New Bug")
         context["form_post_url"] = reverse("bugs-new")
         return context
 
@@ -172,11 +172,9 @@ class Edit(UpdateView):
                 field in new_data
                 and self._values_before_update[field] != new_data[field]
             ):
-                result += "%s: %s -> %s\n" % (
-                    field.title(),
-                    self._values_before_update[field],
-                    new_data[field],
-                )
+                _before_update = self._values_before_update[field]
+                _after_update = new_data[field]
+                result += f"{field.title()}: {_before_update} -> {_after_update}\n"
         if result:
             add_comment([self.object], result, self.request.user)
 
