@@ -3,10 +3,12 @@
 from django.conf import settings
 from django.contrib import messages
 from django.contrib.auth import get_user_model, views
+from django.contrib.auth.decorators import login_required
 from django.http import HttpResponseRedirect
 from django.shortcuts import get_object_or_404, render
 from django.urls import reverse, reverse_lazy
 from django.utils import timezone
+from django.utils.decorators import method_decorator
 from django.utils.translation import gettext_lazy as _
 from django.views.generic.base import RedirectView, View
 
@@ -18,6 +20,14 @@ from tcms.signals import USER_REGISTERED_SIGNAL
 User = get_user_model()  # pylint: disable=invalid-name
 
 
+try:
+    from django_tenants.utils import get_public_schema_name
+except ImportError:
+
+    def get_public_schema_name():  # pylint: disable=nested-function-found
+        return "public"
+
+
 class LoginViewWithCustomTemplate(
     views.LoginView
 ):  # pylint: disable=missing-permission-required
@@ -39,7 +49,7 @@ class Register(View):  # pylint: disable=missing-permission-required
     success_url = reverse_lazy("core-views-index")
 
     def post(self, request):
-        """ Post request handler. """
+        """Post request handler."""
         form = self.form_class(data=request.POST, files=request.FILES)
         if not form.is_valid():
             return render(request, self.template_name, {"form": form})
@@ -75,21 +85,21 @@ class Register(View):  # pylint: disable=missing-permission-required
 
     @staticmethod
     def show_messages_with_site_admins_emails_as_links(request):
-        """ Show messages with site admins emails as links. """
+        """Show messages with site admins emails as links."""
         for name, email in settings.ADMINS:
-            mailto = '<a href="mailto:{}">{}</a>'.format(email, name)
+            mailto = f'<a href="mailto:{email}">{name}</a>'
             messages.add_message(request, messages.WARNING, mailto)
 
     @staticmethod
     def show_messages_with_super_user_emails_as_links(request):
-        """ Show messages with super users emails as links. """
+        """Show messages with super users emails as links."""
         for user in User.objects.filter(is_superuser=True):
             email_display_name = user.get_full_name() or user.username
-            mailto = '<a href="mailto:{}">{}</a>'.format(user.email, email_display_name)
+            mailto = f'<a href="mailto:{user.email}">{email_display_name}</a>'
             messages.add_message(request, messages.INFO, mailto)
 
     def get(self, request):
-        """ Get request handler. """
+        """Get request handler."""
         return render(request, self.template_name, {"form": self.form_class()})
 
 
@@ -140,3 +150,22 @@ class Profile(View):  # pylint: disable=missing-permission-required
     def get(self, request, username):
         user = get_object_or_404(User, username=username)
         return HttpResponseRedirect(reverse("admin:auth_user_change", args=[user.pk]))
+
+
+@method_decorator(
+    login_required, name="dispatch"
+)  # pylint: disable=missing-permission-required
+class UsersAndGroupsRouter(View):
+    http_method_names = ["get"]
+
+    def get(self, request, *args, **kwargs):
+        if request.user.is_superuser:
+            return HttpResponseRedirect("/admin/auth/")
+
+        if (
+            hasattr(request, "tenant")
+            and request.tenant.schema_name != get_public_schema_name()
+        ):
+            return HttpResponseRedirect("/admin/tcms_tenants/tenant_authorized_users/")
+
+        return HttpResponseRedirect("/admin/auth/")
