@@ -1,4 +1,4 @@
-# Copyright (c) 2019 Alexander Todorov <atodorov@MrSenko.com>
+# Copyright (c) 2019-2021 Alexander Todorov <atodorov@MrSenko.com>
 
 # Licensed under the GPL 2.0: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 
@@ -8,8 +8,8 @@ from tcms.management.models import Classification
 from tcms.rpc.decorators import permissions_required
 
 
-@permissions_required('management.view_classification')
-@rpc_method(name='Classification.filter')
+@permissions_required("management.view_classification")
+@rpc_method(name="Classification.filter")
 def filter(query):  # pylint: disable=redefined-builtin
     """
     .. function:: RPC Classification.filter(query)
@@ -21,4 +21,4 @@ def filter(query):  # pylint: disable=redefined-builtin
         :return: Serialized list of :class:`tcms.management.models.Classification` objects
         :rtype: dict
     """
-    return Classification.to_xmlrpc(query)
+    return list(Classification.objects.filter(**query).values("id", "name").distinct())
