@@ -47,6 +47,11 @@ if DATABASES["default"]["ENGINE"].find("mysql") > -1:
     )
 
 
+# New setting since Django 3.2, used internally
+# DO NOT CHANGE
+DEFAULT_AUTO_FIELD = "django.db.models.AutoField"
+
+
 # Administrators error report email settings
 ADMINS = [
     # ('Your Name', 'your_email@example.com'),
@@ -87,6 +92,16 @@ DEFAULT_GROUPS = ["Tester"]
 AUTO_APPROVE_NEW_USERS = True
 
 
+# Set to False if you want to enforce account creation by admins.
+REGISTRATION_ENABLED = (
+    os.environ.get("KIWI_REGISTRATION_ENABLED", "True").lower() == "true"
+)
+
+
+# By default a simple CAPTCHA challenge is enabled in registration page
+USE_CAPTCHA = True
+
+
 # How often will session cookies expire? We set this to 24hrs by default.
 # You may override based on your security policies
 # https://docs.djangoproject.com/en/2.1/ref/settings/#session-cookie-age
@@ -128,6 +143,7 @@ AUTHENTICATION_BACKENDS = [
 
 # WARNING: Do not change this unless you know what you are doing !!!
 MIDDLEWARE = [
+    "tcms.core.middleware.CheckDBStructureExistsMiddleware",
     "django.contrib.sessions.middleware.SessionMiddleware",
     "django.middleware.locale.LocaleMiddleware",
     "django.middleware.common.CommonMiddleware",
@@ -135,8 +151,6 @@ MIDDLEWARE = [
     "django.contrib.auth.middleware.AuthenticationMiddleware",
     "django.contrib.messages.middleware.MessageMiddleware",
     "simple_history.middleware.HistoryRequestMiddleware",
-    "tcms.core.middleware.CheckSettingsMiddleware",
-    "tcms.core.middleware.CheckUnappliedMigrationsMiddleware",
 ]
 
 
@@ -269,6 +283,8 @@ INSTALLED_APPS = TENANT_APPS + [
     "django.contrib.messages",
     "django.contrib.sessions",
     "django.contrib.staticfiles",
+    "django.forms",
+    "captcha",
     "colorfield",
     "django_extensions",
     "tree_queries",
@@ -291,6 +307,8 @@ MENU_ITEMS = [
             (_("New Test Plan"), reverse_lazy("plans-new")),
             ("-", "-"),
             (_("New Test Case"), reverse_lazy("testcases-new")),
+            ("-", "-"),
+            (_("New Test Run"), reverse_lazy("testruns-new")),
             ("-", "-") if "tcms.bugs.apps.AppConfig" in INSTALLED_APPS else (),
             (_("New Bug"), reverse_lazy("bugs-new"))
             if "tcms.bugs.apps.AppConfig" in INSTALLED_APPS
@@ -329,7 +347,7 @@ MENU_ITEMS = [
     (
         _("ADMIN"),
         [
-            (_("Users and groups"), "/admin/auth/"),
+            (_("Users and groups"), reverse_lazy("users-and-groups-router")),
             ("-", "-"),
             (_("Everything else"), "/admin/"),
         ],
@@ -339,12 +357,11 @@ MENU_ITEMS = [
 
 # last element is always PLUGINS so we can easily extend & override it
 for plugin in pkg_resources.iter_entry_points("kiwitcms.plugins"):
-    plugin_menu = import_module("%s.menu" % plugin.module_name)
+    plugin_menu = import_module(f"{plugin.module_name}.menu")
     MENU_ITEMS[-1][1].extend(plugin_menu.MENU_ITEMS)
 
 # redefine the help menu in the navigation bar
 HELP_MENU_ITEMS = [
-    ("https://kiwitcms.discourse.group", _("Forum")),
     ("https://github.com/kiwitcms/Kiwi/issues/new/choose", _("Report an Issue")),
     (
         "https://stackoverflow.com/questions/tagged/kiwi-tcms",
@@ -364,9 +381,10 @@ SESSION_SERIALIZER = "django.contrib.sessions.serializers.JSONSerializer"
 SESSION_ENGINE = "django.contrib.sessions.backends.cached_db"
 
 # WARNING: do not edit. The stock JSONRPC handler does not HTML escape !!!
+# Stock handlers don't serialize timedelta into a meaningfull value
 MODERNRPC_HANDLERS = [
-    "modernrpc.handlers.XMLRPCHandler",
-    "tcms.handlers.SafeJSONRPCHandler",
+    "tcms.handlers.KiwiTCMSXmlRpcHandler",
+    "tcms.handlers.KiwiTCMSJsonRpcHandler",
 ]
 
 # in alphabetic order
@@ -379,7 +397,9 @@ MODERNRPC_METHODS_MODULES = [
     "tcms.rpc.api.category",
     "tcms.rpc.api.classification",
     "tcms.rpc.api.component",
+    "tcms.rpc.api.environment",
     "tcms.rpc.api.markdown",
+    "tcms.rpc.api.kiwitcms",
     "tcms.rpc.api.plantype",
     "tcms.rpc.api.priority",
     "tcms.rpc.api.product",
@@ -466,7 +486,10 @@ MESSAGE_TAGS = {
     messages.ERROR: "danger",
 }
 
-TEMP_DIR = pathlib.Path(tempfile.gettempdir())
+if os.path.isdir("/var/tmp"):  # nosec: B108
+    TEMP_DIR = pathlib.Path("/var/tmp")  # nosec: B108
+else:
+    TEMP_DIR = pathlib.Path(tempfile.gettempdir())
 
 # See https://github.com/django-guardian/django-guardian/issues/726
 ANONYMOUS_USER_NAME = "AnonymousUser"
