@@ -24,7 +24,7 @@ def breakdown(query=None):
     if query is None:
         query = {}
 
-    test_cases = TestCase.objects.filter(**query).filter()
+    test_cases = TestCase.objects.filter(**query).distinct()
 
     manual_count = test_cases.filter(is_automated=False).count()
     automated_count = test_cases.filter(is_automated=True).count()
@@ -48,12 +48,12 @@ def _get_field_count_map(test_cases, expression, field):
     query_set_confirmed = (
         test_cases.filter(case_status__is_confirmed=True)
         .values(field)
-        .annotate(count=Count(expression))
+        .annotate(count=Count(expression, distinct=True))
     )
     query_set_not_confirmed = (
         test_cases.exclude(case_status__is_confirmed=True)
         .values(field)
-        .annotate(count=Count(expression))
+        .annotate(count=Count(expression, distinct=True))
     )
     return {
         str(_("CONFIRMED")): _map_query_set(query_set_confirmed, field),
@@ -226,6 +226,22 @@ def test_case_health(query=None):
     return data
 
 
+@http_basic_auth_login_required
+@rpc_method(name="Testing.individual_test_case_health")
+def individual_test_case_health_simple(query=None):
+
+    if query is None:
+        query = {}
+
+    res = (
+        TestExecution.objects.filter(**query)
+        .values("run__plan", "case_id", "status__name", "status__weight")
+        .order_by("case", "run__plan", "status__weight")
+    )
+
+    return list(res)
+
+
 def _remove_all_excellent_executions(data):
     for key in dict.fromkeys(data):
         if data[key]["count"]["fail"] == 0:
